================================
dictyBase Mutants (:mod:`obiDictyMutants`)
================================

This module presents data on `Mutant phenotypes 
<http://dictybase.org/Downloads/>`_ from the dictyBase.

.. automodule:: Orange.bio.obiDictyMutants
   :members:
   :member-order: bysource

